@@ -1,23 +1,23 @@
 ;;; emacspeak-actions.el --- Emacspeak actions -- callbacks that can be associated with portions of a buffer
-;;; $Id: emacspeak-actions.el,v 9.0 1998/10/24 05:17:28 raman Exp $
-;;; $Author: raman $ 
-;;; Define emacspeak actions for various modes 
-;;; Keywords:emacspeak, audio interface to emacs actions 
-;;{{{  LCD Archive entry: 
+;;; $Id: emacspeak-actions.el,v 11.0 1999/11/29 16:58:57 raman Exp $
+;;; $Author: raman $
+;;; Define emacspeak actions for various modes
+;;; Keywords:emacspeak, audio interface to emacs actions
+;;{{{  LCD Archive entry:
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@adobe.com 
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/10/24 05:17:28 $ |
-;;;  $Revision: 9.0 $ | 
+;;; $Date: 1999/11/29 16:58:57 $ |
+;;;  $Revision: 11.0 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995, 1996, 1997, 1998   T. V. Raman  Adobe Systems Incorporated
-;;; Copyright (c) 1995 by T. V. Raman 
-;;; All Rights Reserved. 
+;;;Copyright (C) 1995, 1996, 1997, 1998, 1999   T. V. Raman  
+;;; Copyright (c) 1995 by T. V. Raman
+;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
 ;;;
@@ -37,21 +37,28 @@
 
 ;;}}}
 
-(require 'cl)
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'emacspeak-speak)
-(require 'emacspeak-sounds)
+
+
+;;; Commentary:
 ;;{{{  Introduction:
 
 ;;; Define mode-specific  actions.
 ;;; Actions are defined by adding them to hook
-;;; emacspeak-<mode-name>-actions-hook 
+;;; emacspeak-<mode-name>-actions-hook
 
 ;;}}}
-;;{{{  Define actions for emacs lisp mode 
+;; 
+;;; Code:
+(require 'cl)
+(declaim  (optimize  (safety 0) (speed 3)))
+(require 'emacspeak-speak)
+(require 'emacspeak-sounds)
+
+;;{{{  Define actions for emacs lisp mode
 
 (defun emacspeak-lisp-blink-matching-paren-when-on-right-paren ()
-  "Defines an emacspeak action on all right parens that causes
+  "Setup action on right parens.
+The defined   emacspeak action   causes
 emacspeak to show the matching paren when the cursor moves across a right paren."
     (save-excursion
       (goto-char (point-min))
@@ -67,10 +74,11 @@ emacspeak to show the matching paren when the cursor moves across a right paren.
           'emacspeak-lisp-blink-matching-paren-when-on-right-paren )
 
 ;;}}}
-;;{{{  Define actions for c and c++ modes 
+;;{{{  Define actions for c and c++ modes
 
 (defun emacspeak-c-speak-semantics-when-on-closing-brace ()
-  "Defines an emacspeak action on all right braces  that causes
+  "Setup action on right braces.
+The defined  action    causes
 emacspeak to speak the semantics of the line
  when the cursor moves across a right brace."
   (save-excursion
@@ -87,11 +95,11 @@ emacspeak to speak the semantics of the line
 
 ;;}}}
 (provide  'emacspeak-actions)
-;;{{{  emacs local variables 
+;;{{{  emacs local variables
 
 ;;; local variables:
 ;;; folded-file: t
 ;;; byte-compile-dynamic: t
-;;; end: 
+;;; end:
 
 ;;}}}
