@@ -1,21 +1,21 @@
 ;;; emacspeak-c.el --- Speech enable CC-mode and friends -- supports C, C++, Java 
-;;; $Id: emacspeak-c.el,v 9.0 1998/10/24 05:17:28 raman Exp $
+;;; $Id: emacspeak-c.el,v 11.0 1999/11/29 16:58:57 raman Exp $
 ;;; $Author: raman $ 
 ;;; DescriptionEmacspeak extensions for C and C++ mode
 ;;; Keywords:emacspeak, audio interface to emacs C, C++
 ;;{{{  LCD Archive entry: 
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@adobe.com 
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/10/24 05:17:28 $ |
-;;;  $Revision: 9.0 $ | 
+;;; $Date: 1999/11/29 16:58:57 $ |
+;;;  $Revision: 11.0 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995, 1996, 1997, 1998   T. V. Raman  Adobe Systems Incorporated
+;;;Copyright (C) 1995, 1996, 1997, 1998, 1999   T. V. Raman  
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -80,11 +80,15 @@
 
 ;;{{{  Electric chars speak
 
+
+
 (defadvice c-electric-star (after emacspeak pre act )
   "Speak what you typed"
   (when (interactive-p)
     (dtk-say "star")))
 
+
+
 (defadvice c-electric-semi&comma (after emacspeak pre act )
   "Speak the line when a statement is completed."
   (when (interactive-p)
@@ -113,6 +117,11 @@
 (when (interactive-p)
 (emacspeak-speak-this-char last-input-char)))
 
+(defadvice c-electric-paren (after emacspeak pre act )
+"Speak the character you inserted"
+(when (interactive-p)
+(emacspeak-speak-this-char last-input-char)))
+
 (defadvice c-electric-pound (after emacspeak pre act )
 "Speak the character you inserted"
 (when (interactive-p)
@@ -199,10 +208,13 @@
 (defadvice  c-beginning-of-defun (after emacspeak pre act)
   "Speak the line."
   (when (interactive-p)
+    (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line)))
+
 (defadvice  c-end-of-defun (after emacspeak pre act)
   "Speak the line."
   (when (interactive-p)
+    (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line)))
 
 ;;}}}
@@ -287,7 +299,9 @@ level")
 (defvar emacspeak-c-syntactic-table 
   (list 
    '(string                 . "  inside multi-line string")
-   '( c                      . "  inside a multi-line C style block comment")
+   '( c                      . "  inside a multi-line C
+style block comment")
+   '(catch-clause . "Exception handling construct")
    '( defun-open             . "  brace that opens a function definition")
    '( defun-close            . "  brace that closes a function definition")
    '( defun-block-intro      . "  the first line in a top-level defun")
@@ -298,7 +312,9 @@ level")
    '( func-decl-cont         . "  the region between a 
 function definition's argument list and the function opening brace")
    '( knr-argdecl-intro      . "  first line of a K&R C argument declaration")
-   '( knr-argdecl            . "  subsequent lines in a K&R C argument declaration")
+   '( knr-argdecl            . "  subsequent lines in a K&R
+C argument declaration")
+   '(inexpr-class . "Anonymous inner class")
    '( topmost-intro          . "  the first line in a topmost construct definition")
    '( topmost-intro-cont     . "  topmost definition continuation lines")
    '( member-init-intro      . "  first line in a member initialization list")
@@ -308,7 +324,9 @@ function definition's argument list and the function opening brace")
    '( block-open             . "  statement block open brace")
    '( block-close            . "  statement block close brace")
    '( brace-list-open        . "  open brace of an enum or static array list")
-   '( brace-list-close       . "  close brace of an enum or static array list")
+   '( brace-list-close       . "  close brace of an enum or
+static array list")
+'( brace-entry-open       . "  first line in an enum or static array list")
    '( brace-list-intro       . "  first line in an enum or static array list")
    '( brace-list-entry       . "  subsequent lines in an enum or static array list")
    '( statement              . "  a C (or like) statement")
@@ -420,6 +438,7 @@ and their meanings. ")
                         (define-key c-mode-base-map "\M-n" 'c-next-statement)
                         (define-key c-mode-base-map "\M-p"
                           'c-previous-statement))
+                      (emacspeak-pronounce-toggle-use-of-dictionaries 'on)
                       (or dtk-split-caps
                           (dtk-toggle-split-caps))
                       (or dtk-allcaps-beep
