@@ -1,22 +1,22 @@
 ;;; emacspeak-enriched.el --- Audio Formatting for Emacs' WYSIWYG RichText  mode
-;;; $Id: emacspeak-enriched.el,v 8.0 1998/05/01 14:15:46 raman Exp $
+;;; $Id: emacspeak-enriched.el,v 11.0 1999/11/29 16:58:57 raman Exp $
 ;;; $Author: raman $ 
 ;;; Description: Emacspeak module to speak voicify rich text
 ;;; Keywords:emacspeak, audio interface to emacs rich text
 ;;{{{  LCD Archive entry: 
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@adobe.com
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/05/01 14:15:46 $ |
-;;;  $Revision: 8.0 $ | 
+;;; $Date: 1999/11/29 16:58:57 $ |
+;;;  $Revision: 11.0 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995, 1996, 1997, 1998   T. V. Raman  Adobe Systems Incorporated
-;;; Copyright (c) 1995 by T. V. Raman Adobe Systems Incorporated 
+;;;Copyright (C) 1995, 1996, 1997, 1998, 1999   T. V. Raman  
+;;; Copyright (c) 1995 by T. V. Raman  
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -64,6 +64,7 @@ Useful in voicifying rich text."
    (save-excursion
      (goto-char start)
      (let ((face nil )
+           (orig start)
            (pos nil)
            (justification-type nil))
        (unless (get-text-property (point) 'justification)
@@ -88,7 +89,7 @@ Useful in voicifying rich text."
                               'auditory-icon
                               justification-type))
          (setq start (point)))
-       (goto-char start)
+       (goto-char orig)
        (while (and  (not (eobp))
                     (< start end))
          (setq face (get-text-property (point) 'face ))
@@ -137,6 +138,7 @@ Useful in voicifying rich text."
 
 ;;; local variables:
 ;;; folded-file: t
+;;; byte-compile-dynamic: t
 ;;; end: 
 
 ;;}}}
