@@ -1,21 +1,21 @@
 ;;; emacspeak-forms.el --- Speech enable Emacs' forms mode  -- provides  a convenient database interface
-;;; $Id: emacspeak-forms.el,v 9.0 1998/10/24 05:17:28 raman Exp $
+;;; $Id: emacspeak-forms.el,v 11.0 1999/11/29 16:58:57 raman Exp $
 ;;; $Author: raman $ 
 ;;; DescriptionEmacspeak extensions for forms-mode 
 ;;; Keywords:emacspeak, audio interface to emacs forms 
 ;;{{{  LCD Archive entry: 
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@adobe.com
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/10/24 05:17:28 $ |
-;;;  $Revision: 9.0 $ | 
+;;; $Date: 1999/11/29 16:58:57 $ |
+;;;  $Revision: 11.0 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995, 1996, 1997, 1998   T. V. Raman  Adobe Systems Incorporated
+;;;Copyright (C) 1995, 1996, 1997, 1998, 1999   T. V. Raman  
 ;;; Copyright (c) 1996 by T. V. Raman 
 ;;; All Rights Reserved. 
 ;;;
@@ -43,6 +43,7 @@
 (require 'emacspeak-fix-interactive)
 (require 'emacspeak-speak)
 (require 'emacspeak-sounds)
+(require 'forms)
 ;;{{{  Introduction:
 
 ;;; Provide additional advice to forms-mode 
@@ -53,33 +54,43 @@
 (defadvice forms-next-record (after emacspeak pre act comp)
   "Provide auditory feedback."
   (when (interactive-p)
-    (emacspeak-auditory-icon 'scroll)
+    (emacspeak-auditory-icon 'select-object)
+    (goto-char (next-single-property-change 
+                (point)
+                'read-only
+                (current-buffer)
+                (point-max)))
     (emacspeak-forms-summarize-current-record)))
 
 (defadvice forms-prev-record (after emacspeak pre act comp)
   "Provide auditory feedback."
   (when (interactive-p)
-    (emacspeak-auditory-icon 'scroll)
+    (emacspeak-auditory-icon 'select-object)
+    (goto-char (next-single-property-change 
+                (point)
+                'read-only
+                (current-buffer)
+                (point-max)))
     (emacspeak-forms-summarize-current-record)))
 
 (defadvice forms-first-record (after emacspeak pre act comp)
   "Provide auditory feedback."
   (when (interactive-p)
-    (emacspeak-auditory-icon 'scroll)
+    (emacspeak-auditory-icon 'select-object)
     (emacspeak-forms-summarize-current-record)))
 
 
 (defadvice forms-last-record (after emacspeak pre act comp)
   "Provide auditory feedback."
   (when (interactive-p)
-    (emacspeak-auditory-icon 'scroll)
+    (emacspeak-auditory-icon 'select-object)
     (emacspeak-forms-summarize-current-record)))
 
 
 (defadvice forms-jump-record (after emacspeak pre act comp)
   "Provide auditory feedback."
   (when (interactive-p)
-    (emacspeak-auditory-icon 'scroll)
+    (emacspeak-auditory-icon 'select-object)
     (emacspeak-forms-summarize-current-record)))
 
 (eval-when (load)
@@ -137,16 +148,30 @@
 
 (eval-when (load)
   (emacspeak-fix-interactive-command-if-necessary 'forms-find-file))
+
 ;;}}}
 ;;{{{ Helper functions
+(defvar emacspeak-forms-current-record-summarizer
+  'emacspeak-forms-speak-field
+"Summarizer function for summarizing a record. Default is to
+speak the first field")
+(make-variable-buffer-local
+ emacspeak-forms-current-record-summarizer)
 
 (defun emacspeak-forms-summarize-current-record ()
-"Summarize the current record by speaking an ntelligent message."
-(declare (special forms--current-record forms--total-records
-                  forms-file))
-(dtk-speak
- (format "Record %s of %s from %s"
-         forms--current-record forms--total-records forms-file)))
+  "Summarize current record"
+  (interactive)
+  (declare (special emacspeak-forms-current-record-summarizer))
+  (funcall emacspeak-forms-current-record-summarizer))
+
+(defun emacspeak-forms-summarize-current-position ()
+  "Summarize current position in list of records"
+  (interactive)
+  (declare (special forms--current-record forms--total-records
+                    forms-file))
+  (dtk-speak
+   (format "Record %s of %s from %s"
+           forms--current-record forms--total-records forms-file)))
 
 (dtk-define-voice-alias 'emacspeak-forms-rw-voice 'paul)
 (dtk-define-voice-alias 'emacspeak-forms-ro-voice 'annotation-voice)
@@ -177,6 +202,78 @@ Assumes that point is at the front of a field value."
     (dtk-speak (concat name " " value ))))
 
       ;;}}}
+;;{{{ smart filters
+
+(defun emacspeak-forms-flush-unwanted-records ()
+  "Prompt for pattern and flush matching lines"
+  (interactive)
+  (let ((pattern (read-from-minibuffer
+                  "Specify filter pattern")))
+    (when (> (length pattern) 0)
+      (flush-lines
+       pattern))))
+
+(defun emacspeak-forms-rerun-filter ()
+  "Rerun  filter --allows us to nuke more matching records"
+  (interactive)
+  (declare (special forms--file-buffer
+                    forms--total-records forms-read-only))
+  (save-excursion
+    (set-buffer forms--file-buffer)
+    (let ((inhibit-read-only t)
+          (file-modified (buffer-modified-p)))
+      (emacspeak-forms-flush-unwanted-records)
+      (if (not file-modified) (set-buffer-modified-p
+                               nil))))
+  (let (ro)
+    (setq forms--total-records
+	  (save-excursion
+	    (prog1
+		(progn
+		  ;;(message "forms: counting records...")
+		  (set-buffer forms--file-buffer)
+		  (bury-buffer (current-buffer))
+		  (setq ro buffer-read-only)
+		  (count-lines (point-min) (point-max))))))
+    (if ro
+	(setq forms-read-only t)))
+  (message "%s records after filtering"
+           forms--total-records))
+
+;;}}}
+;;{{{ emacspeak forms find file 
+(defun emacspeak-forms-find-file (filename)
+  "Visit a forms file"
+  (interactive
+   (list
+   (read-file-name "Forms file: "
+                   (concat emacspeak-dir "/forms/"))))
+  (forms-find-file filename))
+
+;;}}}
+;;{{{ bind smart filters
+(declaim (special forms-mode-map forms-mode-ro-map
+                  forms-mode-edit-map))
+(add-hook 'forms-mode-hook
+(function
+(lambda nil 
+(mapcar 
+ (function
+  (lambda (map)
+    (define-key map "\C-m" 'emacspeak-forms-rerun-filter)))
+ (list forms-mode-ro-map 
+   forms-mode-map 
+   forms-mode-edit-map ))
+(mapcar 
+ (function
+  (lambda (map)
+    (define-key map "." 'emacspeak-forms-summarize-current-position)))
+ (list forms-mode-ro-map 
+       forms-mode-map 
+       forms-mode-edit-map )))))
+  
+
+;;}}}
 (provide  'emacspeak-forms)
 ;;{{{  emacs local variables 
 
