@@ -1,21 +1,21 @@
 ;;; emacspeak-gnus.el --- Speech enable GNUS -- Fluent spoken access to usenet
-;;; $Id: emacspeak-gnus.el,v 9.0 1998/10/24 05:17:28 raman Exp $
+;;; $Id: emacspeak-gnus.el,v 11.0 1999/11/29 16:58:57 raman Exp $
 ;;; $Author: raman $ 
 ;;; Description:  Emacspeak extension to speech enable Gnus
 ;;; Keywords: Emacspeak, Gnus, Advice, Spoken Output, News
 ;;{{{  LCD Archive entry: 
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@adobe.com 
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/10/24 05:17:28 $ |
-;;;  $Revision: 9.0 $ | 
+;;; $Date: 1999/11/29 16:58:57 $ |
+;;;  $Revision: 11.0 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995, 1996, 1997, 1998   T. V. Raman  Adobe Systems Incorporated
+;;;Copyright (C) 1995, 1996, 1997, 1998, 1999   T. V. Raman  
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -136,7 +136,7 @@ reading news."
 
 (defsubst emacspeak-gnus-summary-speak-subject ()
   (emacspeak-dtk-sync)
-  (dtk-speak (gnus-summary-subject-string )))
+  (dtk-speak (gnus-summary-article-subject )))
 
 ;;}}}
 ;;{{{ Advise top-level gnus command
@@ -176,7 +176,7 @@ reading news."
 an object has been opened."
   (when (interactive-p) 
     (emacspeak-auditory-icon 'open-object)
-    (dtk-speak (gnus-summary-subject-string))))
+    (dtk-speak (gnus-summary-article-subject))))
 
 (defadvice gnus-group-prev-group (around emacspeak pre act)
   "Speak the newsgroup line.
@@ -244,7 +244,7 @@ this group is being deselected."
             (dtk-speak "No more articles ")
           (progn 
             (emacspeak-auditory-icon 'select-object ))
-          (dtk-speak (gnus-summary-subject-string )))
+          (dtk-speak (gnus-summary-article-subject )))
         ad-return-value )
     ad-return-value ))
 
@@ -258,7 +258,7 @@ Produce an auditory icon if possible."
             (dtk-speak "No more articles ")
           (progn 
             (emacspeak-auditory-icon 'select-object )
-            (dtk-speak (gnus-summary-subject-string )))))
+            (dtk-speak (gnus-summary-article-subject )))))
     ad-return-value ))
 
 (defadvice gnus-summary-prev-unread-subject  (around  emacspeak pre act)
@@ -271,7 +271,7 @@ Produce an auditory icon if possible."
             (dtk-speak "No more unread articles ")
           (progn 
             (emacspeak-auditory-icon 'select-object )
-            (dtk-speak (gnus-summary-subject-string ))))
+            (dtk-speak (gnus-summary-article-subject ))))
         ad-return-value )
     ad-return-value ))
 
@@ -285,7 +285,7 @@ Produce an auditory icon if possible."
             (dtk-speak "No more articles ")
           (progn 
             (emacspeak-auditory-icon 'select-object )
-            (dtk-speak (gnus-summary-subject-string )))))
+            (dtk-speak (gnus-summary-article-subject )))))
     ad-return-value )
   ad-return-value )
 
@@ -299,7 +299,7 @@ Produce an auditory icon if possible."
               (dtk-speak "No more articles ")
             (progn 
               (emacspeak-auditory-icon 'select-object )
-              (dtk-speak (gnus-summary-subject-string ))))
+              (dtk-speak (gnus-summary-article-subject ))))
           ad-return-value )
       ad-return-value ))
 
