@@ -1,21 +1,21 @@
 ;;; emacspeak-keymap.el --- Setup all keymaps and keybindings provided by Emacspeak
-;;; $Id: emacspeak-keymap.el,v 9.0 1998/10/24 05:17:28 raman Exp $
+;;; $Id: emacspeak-keymap.el,v 11.0 1999/11/29 16:58:57 raman Exp $
 ;;; $Author: raman $ 
 ;;; Description:  Module for setting up emacspeak keybindings
 ;;; Keywords: Emacspeak
 ;;{{{  LCD Archive entry: 
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@adobe.com 
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/10/24 05:17:28 $ |
-;;;  $Revision: 9.0 $ | 
+;;; $Date: 1999/11/29 16:58:57 $ |
+;;;  $Revision: 11.0 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995, 1996, 1997, 1998   T. V. Raman  Adobe Systems Incorporated
+;;;Copyright (C) 1995, 1996, 1997, 1998, 1999   T. V. Raman  
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -74,7 +74,7 @@
 
 ;;}}}
 ;;{{{  The actual bindings.
-
+(define-key help-map "e" 'emacspeak-websearch-emacspeak-archive)
 (define-key help-map emacspeak-prefix
   'emacspeak-describe-emacspeak)
 ;;;Let's bind find-func on useful help keys 
@@ -94,7 +94,9 @@
 (define-key emacspeak-keymap '[up]  'emacspeak-read-previous-line)
 (define-key emacspeak-keymap "x" 'emacspeak-view-register)
 (define-key emacspeak-keymap "w" 'emacspeak-speak-word)
-(define-key emacspeak-keymap "W" 'emacspeak-speak-spell-current-word)
+(define-key emacspeak-keymap "W"
+  'emacspeak-speak-spell-current-word)
+(define-key emacspeak-keymap "u" 'emacspeak-dejanews-browse-group)
 (define-key emacspeak-keymap "v" 'emacspeak-speak-version)
 (define-key emacspeak-keymap "\C-v" 'view-mode)
 (define-key emacspeak-keymap "t" 'emacspeak-speak-time )
@@ -102,11 +104,11 @@
 (define-key emacspeak-keymap "r" 'emacspeak-speak-region)
 (define-key emacspeak-keymap "R" 'emacspeak-speak-rectangle)
 (define-key emacspeak-keymap "q" 'emacspeak-toggle-speak-messages)
-(define-key emacspeak-keymap "p" 'emacspeak-speak-paragraph)
-(define-key emacspeak-keymap "o" 'emacspeak-voicify-region)
 (define-key emacspeak-keymap "n" 'emacspeak-speak-rest-of-buffer)
 (define-key emacspeak-keymap "m" 'emacspeak-speak-mode-line)
-(define-key emacspeak-keymap "\C-l" 'emacspeak-speak-line-number)
+(define-key emacspeak-keymap "\C-l"
+  'emacspeak-speak-line-number)
+(define-key emacspeak-keymap "|" 'emacspeak-speak-line-set-column-filter)
 (define-key emacspeak-keymap "l" 'emacspeak-speak-line)
 (define-key emacspeak-keymap "k" 'emacspeak-speak-current-kill )
 (define-key emacspeak-keymap "\C-@" 'emacspeak-speak-current-mark )
@@ -119,30 +121,38 @@
 (define-key emacspeak-keymap "\C-j" 'emacspeak-hide-speak-block-sans-prefix)
 (define-key emacspeak-keymap  "f"
   'emacspeak-speak-buffer-filename )
-(define-key emacspeak-keymap  "\C-f" 'emacspeak-frame-label-or-switch-to-labelled-frame )
+(define-key emacspeak-keymap  "\M-f"
+  'emacspeak-frame-label-or-switch-to-labelled-frame )
+(define-key emacspeak-keymap  "\C-f" 'emacspeak-forms-find-file )
 (define-key emacspeak-keymap "c" 'emacspeak-speak-char)
 (define-key emacspeak-keymap "b" 'emacspeak-speak-buffer)
 (define-key emacspeak-keymap "a" 'emacspeak-speak-message-again )
-(define-key emacspeak-keymap "\C-s" 'dtk-emergency-restart )
-(define-key emacspeak-keymap "\C-q" 'emacspeak-toggle-comint-autospeak)
+(define-key emacspeak-keymap "\C-s" 'tts-restart )
+(define-key emacspeak-keymap "\C-q"
+  'emacspeak-toggle-comint-autospeak)
+(define-key emacspeak-keymap "o" 'emacspeak-toggle-comint-output-monitor)
 (define-key emacspeak-keymap "\C-m"  'emacspeak-speak-continuously)
 (define-key emacspeak-keymap "\C-i" 'emacspeak-table-display-table-in-region)
 (define-key emacspeak-keymap "\C-h" 'emacspeak-learn-mode)
+(define-key emacspeak-keymap "\M-h" 'emacspeak-speak-browse-linux-howto)
 (define-key emacspeak-keymap "\C-b" 'emacspeak-submit-bug )
 (define-key emacspeak-keymap "\"" 'emacspeak-speak-sexp-interactively)
 (define-key emacspeak-keymap "p" 'dtk-pause)
 (define-key emacspeak-keymap "]" 'emacspeak-speak-page-interactively)
-(define-key emacspeak-keymap "[" 'emacspeak-speak-paragraph)
+(define-key emacspeak-keymap "{" 'emacspeak-speak-paragraph)
+(define-key emacspeak-keymap "[" 'emacspeak-speak-page)
 (define-key emacspeak-keymap "P" 'emacspeak-speak-paragraph-interactively)
 (define-key emacspeak-keymap "M" 'emacspeak-speak-minor-mode-line)
 (define-key emacspeak-keymap "L" 'emacspeak-speak-line-interactively)
 (define-key emacspeak-keymap "H" 'emacspeak-speak-help-interactively)
 (define-key emacspeak-keymap "B" 'emacspeak-speak-buffer-interactively)
 (define-key emacspeak-keymap "A" 'emacspeak-appt-repeat-announcement)
-(define-key emacspeak-keymap "?" 'search-backward )
+(define-key emacspeak-keymap "?"
+  'emacspeak-websearch-dispatch )
 (define-key emacspeak-keymap "."
   'emacspeak-speak-browse-buffer )
 (define-key emacspeak-keymap ";" 'emacspeak-realaudio )
+(define-key emacspeak-keymap ":" 'emacspeak-realaudio-browse )
 (define-key emacspeak-keymap "C" 'emacspeak-speak-display-char)
 (define-key emacspeak-keymap "\C-o" 'emacspeak-speak-other-window )
 (define-key emacspeak-keymap "\C-c"
@@ -151,11 +161,14 @@
   'emacspeak-copy-current-file)
 (define-key emacspeak-keymap "\M-l"
   'emacspeak-link-current-file)
-(define-key emacspeak-keymap "\M-s" 'emacspeak-symlink-current-file)
+(define-key emacspeak-keymap "\M-s"
+  'emacspeak-symlink-current-file)
+(define-key emacspeak-keymap "!" 'emacspeak-speak-run-shell-command)
 (define-key emacspeak-keymap "\C-y" 'emacspeak-clipboard-paste)
 (define-key emacspeak-keymap "\C-p" 'emacspeak-speak-previous-window)
 (define-key emacspeak-keymap "\C-n" 'emacspeak-speak-next-window )
-(define-key emacspeak-keymap ")" 'emacspeak-use-customized-blink-paren)
+(define-key emacspeak-keymap "(" 'emacspeak-aumix)
+(define-key emacspeak-keymap "\177" 'cd-tool)
 (define-key emacspeak-keymap "'" 'emacspeak-speak-sexp)
 (define-key emacspeak-keymap "=" 'emacspeak-speak-current-column)
 (define-key emacspeak-keymap "%" 'emacspeak-speak-current-percentage)
@@ -171,7 +184,7 @@
 (define-key emacspeak-keymap "\M-d"
   'emacspeak-pronounce-dispatch)
 (define-key emacspeak-keymap "\M-b" 'emacspeak-pronounce-define-local-pronunciation)
-(define-key emacspeak-keymap "\M-a" 'emacspeak-toggle-action-mode)
+(define-key emacspeak-keymap "\M-a" 'emacspeak-toggle-midi-icons)
 (define-key emacspeak-keymap "\M-m" 'emacspeak-toggle-mail-alert)
 (define-key emacspeak-keymap "\M-v"
   'emacspeak-show-personality-at-point)
@@ -193,7 +206,7 @@
   'emacspeak-view-emacspeak-faq)
 (define-key emacspeak-keymap "D" 'emacspeak-view-emacspeak-doc)
 ;;; submap for setting dtk:
-(define-key emacspeak-dtk-submap "z" 'emacspeak-zap-dtk)
+(define-key emacspeak-dtk-submap "z" 'emacspeak-zap-tts)
 (define-key emacspeak-dtk-submap "t" 'emacspeak-dial-dtk)
 (define-key emacspeak-dtk-submap "w" 'emacspeak-toggle-word-echo)
 (define-key emacspeak-dtk-submap "V" 'emacspeak-dtk-speak-version)
@@ -216,6 +229,7 @@
 (define-key emacspeak-dtk-submap "c" 'dtk-toggle-capitalization)
 (define-key emacspeak-dtk-submap "C" 'dtk-toggle-allcaps-beep)
 (define-key emacspeak-dtk-submap "b" 'dtk-toggle-debug)
+(define-key emacspeak-dtk-submap "\M-\C-b" 'tts-show-debug-buffer)
 (define-key emacspeak-dtk-submap "a" 'dtk-add-cleanup-pattern)
 
 
