@@ -1,21 +1,21 @@
 ;;; emacspeak-man.el --- Speech enable Man mode -- Use this for UNIX Man pages
-;;; $Id: emacspeak-man.el,v 9.0 1998/10/24 05:17:28 raman Exp $
+;;; $Id: emacspeak-man.el,v 11.0 1999/11/29 16:58:57 raman Exp $
 ;;; $Author: raman $ 
 ;;; DescriptionEmacspeak extensions for man-mode
 ;;; Keywords:emacspeak, audio interface to emacs man 
 ;;{{{  LCD Archive entry: 
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@adobe.com 
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/10/24 05:17:28 $ |
-;;;  $Revision: 9.0 $ | 
+;;; $Date: 1999/11/29 16:58:57 $ |
+;;;  $Revision: 11.0 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995, 1996, 1997, 1998   T. V. Raman  Adobe Systems Incorporated
+;;;Copyright (C) 1995, 1996, 1997, 1998, 1999   T. V. Raman  
 ;;; Copyright (c) 1995 by T. V. Raman 
 ;;; All Rights Reserved. 
 ;;;
@@ -43,6 +43,7 @@
 (require 'emacspeak-sounds)
 (require 'voice-lock)
 (require 'emacspeak-keymap)
+(eval-when-compile (require 'man))
 ;;{{{  Introduction:
 
 ;;; Provide additional advice to man-mode 
@@ -82,8 +83,13 @@
 Also provide an auditory icon"
   (setq paragraph-start "^[\011\012\014]*$"
         paragraph-separate "^[\011\012\014]*$")
+  (modify-syntax-entry 10 " ")
+  (setq imenu-generic-expression
+        '((nil "\n\\([A-Z].*\\)" 1)     ; SECTION, but not TITLE
+          ("*Subsections*" "^   \\([A-Z].*\\)" 1)))
+  (voice-lock-mode 1)
+  (dtk-set-punctuations "all")
   (emacspeak-auditory-icon 'help))
-  
 
 (defadvice   Man-goto-section  (after emacspeak pre act )
   "Speak the line"
@@ -124,22 +130,42 @@ Also provide an auditory icon"
 ;;}}}
 ;;{{{  Additional commands
 
+(defun emacspeak-man-speak-this-section ()
+  "Speak current section"
+  (interactive)
+  (save-excursion
+    (let ((start (point))
+          (end nil))
+      (condition-case nil
+          (progn
+            (Man-next-section 1)
+            (setq end (point)))
+          (error (setq end (point-max))))
+(emacspeak-auditory-icon 'select-object)
+      (emacspeak-speak-region start end ))))
+
 (defun emacspeak-man-browse-man-page ()
   "Browse the man page --read it a paragraph at a time"
   (interactive)
   (emacspeak-execute-repeatedly 'forward-paragraph))
-
+(autoload 'emacspeak-view-line-to-top 
+"emacspeak-view" "Move current line to top of window"  t)
 (declaim (special Man-mode-map))
 (eval-when (load)
   (emacspeak-keymap-remove-emacspeak-edit-commands Man-mode-map))
 (declaim (special  Man-mode-map))
+(define-key Man-mode-map ";"
+  'emacspeak-speak-current-window)
+(define-key Man-mode-map "\M-j" 'imenu)
+(define-key Man-mode-map "\M- " 'emacspeak-man-speak-this-section)
 (define-key Man-mode-map "." 'emacspeak-man-browse-man-page)
+(define-key Man-mode-map "t" 'emacspeak-view-line-to-top)
+(define-key Man-mode-map "'" 'emacspeak-speak-rest-of-buffer)
 (define-key Man-mode-map "[" 'backward-paragraph)
 (define-key Man-mode-map "]" 'forward-paragraph)
 
+
 ;;}}}
-
-
 (provide  'emacspeak-man)
 ;;{{{  emacs local variables 
 
