@@ -1,5 +1,5 @@
 ;;; emacspeak-outline.el --- Speech enable Outline --   Browsing  Structured Documents
-;;; $Id: emacspeak-outline.el,v 9.0 1998/10/24 05:17:28 raman Exp $
+;;; $Id: emacspeak-outline.el,v 11.0 1999/11/29 16:58:57 raman Exp $
 ;;; $Author: raman $ 
 ;;; DescriptionEmacspeak extensions for outline-mode
 ;;; Keywords:emacspeak, audio interface to emacs Outlines
@@ -9,7 +9,7 @@
 ;;; emacspeak| T. V. Raman |raman@crl.dec.com 
 ;;; A speech interface to Emacs |
 ;;; $date: $ |
-;;;  $Revision: 9.0 $ | 
+;;;  $Revision: 11.0 $ | 
 ;;; Location undetermined
 ;;;
 
@@ -63,6 +63,7 @@
 (defvar outline-voice-lock-keywords
   nil
   "Additional expressions to highlight in Outline mode.")
+(make-variable-buffer-local 'outline-regexp)
 
 (setq outline-voice-lock-keywords
 '(;;
@@ -110,6 +111,8 @@
   "Speak the line."
   (when (interactive-p)
     (emacspeak-auditory-icon 'large-movement)
+    (and (looking-at "^$")
+    (emacspeak-skip-blank-lines-backward))
     (emacspeak-speak-line )))
 
 (defadvice outline-previous-visible-heading (after emacspeak pre act comp)
@@ -210,8 +213,14 @@
 ;;}}}
 ;;{{{  Interactive speaking of sections
 
+(defvar emacspeak-outline-dont-query-before-speaking t
+"*Option to control prompts when speaking  outline sections.")
+
+
 (defun emacspeak-outline-speak-heading (what direction)
-  "Function used by all interactive section speaking commands. "
+  "Function used by all interactive section speaking
+commands. "
+  (declare (special emacspeak-outline-query-before-speaking))
   (let ((start nil)
         (end nil))
     (funcall what  direction)
@@ -223,10 +232,11 @@
             (funcall what 1)
             (setq end (point)))
         (error (setq end (point-max)))))
-    (and (y-or-n-p
+    (when (or  emacspeak-outline-dont-query-before-speaking
+             (y-or-n-p
           (format  "Speak %s lines from section %s"
                    (count-lines start end )
-                   (thing-at-point 'line)))
+                   (thing-at-point 'line))))
          (emacspeak-speak-region start end ))))
 
 (defun emacspeak-outline-speak-next-heading ()
@@ -266,10 +276,12 @@ except that the outline section is optionally spoken"
             (outline-next-visible-heading 1)
             (setq end (point)))
         (error (setq end (point-max)))))
-    (and (y-or-n-p
+    (and
+     (or emacspeak-outline-dont-query-before-speaking
+         (y-or-n-p
           (format "Speak %s lines from section %s"
                   (count-lines start end)
-                  (thing-at-point 'line)))
+                  (thing-at-point 'line))))
          (emacspeak-speak-region start end ))))
 
 
@@ -292,7 +304,7 @@ except that the outline section is optionally spoken"
 (add-hook 'outline-minor-mode-hook 'emacspeak-outline-setup-keys)          
 ;;; voice lock outlines
 (add-hook 'outline-mode-hook 'emacspeak-outline-voice-lock-setup)
-(add-hook 'outline-minor-mode-hook 'emacspeak-outline-conditional-voice-lock-setup)
+;(add-hook 'outline-minor-mode-hook 'emacspeak-outline-conditional-voice-lock-setup)
 
 
 
