@@ -1,23 +1,23 @@
 ;;; emacspeak-pronounce.el --- Implements Emacspeak pronunciation dictionaries
-;;; $Id: emacspeak-pronounce.el,v 9.0 1998/10/24 05:17:28 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-pronounce.el,v 11.0 1999/11/29 16:58:57 raman Exp $
+;;; $Author: raman $
 ;;; Description: Emacspeak pronunciation dictionaries
 ;;; Keywords:emacspeak, audio interface to emacs customized pronunciation
-;;{{{  LCD Archive entry: 
+;;{{{  LCD Archive entry:
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@adobe.com
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/10/24 05:17:28 $ |
-;;;  $Revision: 9.0 $ | 
+;;; $Date: 1999/11/29 16:58:57 $ |
+;;;  $Revision: 11.0 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995, 1996, 1997, 1998   T. V. Raman  Adobe Systems Incorporated
-;;; Copyright (c) 1995 by T. V. Raman Adobe Systems Incorporated 
-;;; All Rights Reserved. 
+;;;Copyright (C) 1995, 1996, 1997, 1998, 1999   T. V. Raman  
+;;; Copyright (c) 1995 by T. V. Raman 
+;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
 ;;;
@@ -37,15 +37,8 @@
 
 ;;}}}
 
-(require 'cl)
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'thingatpt)
-(require 'emacspeak-sounds)
-(eval-when (compile)
-                                        ;avoid recursive include during compile
 
-  (provide 'emacspeak-pronounce)
-  (require 'dtk-speak))
+;;; Commentary:
 ;;{{{  Introduction
 
 ;;;This module implements user customizable pronunciation dictionaries
@@ -55,104 +48,119 @@
 ;;;sessions. This module implements the user interface to the custom
 ;;;dictionary as well as providing the internal API used by the rest
 ;;;of emacspeak in using the dictionary.
-;;;Algorithm: 
+;;;Algorithm:
 
 ;;;The persistent dictionary is a hash table where the hash keys are
 ;;;filenames, directory names, or major-mode names. The hash values
 ;;;are association lists defining the dictionary. Users of this module
 ;;;can retrieve a dictionary made up of all applicable association
-;;;lists for a given file. 
+;;;lists for a given file.
 
 ;;}}}
+;; 
+;;; Code:
+(require 'cl)
+(declaim  (optimize  (safety 0) (speed 3)))
+(require 'thingatpt)
+(require 'emacspeak-sounds)
+(eval-when (compile)
+                                        ;avoid recursive include during compile
+
+  (provide 'emacspeak-pronounce)
+  (require 'dtk-speak))
 ;;{{{  Dictionary structure:
 
 (defvar emacspeak-pronounce-dictionaries (make-hash-table )
-"Hash table holding emacspeak's persistent pronunciation dictionaries.
+  "Hash table holding emacspeak's persistent pronunciation dictionaries.
 Keys are either filenames, directory names, or major mode names.
-Values are alists containing string.pronunciation pairs. ")
+Values are alists containing string.pronunciation pairs.")
 
 (defsubst emacspeak-pronounce-set-dictionary (key pr-alist)
-(declare (special emacspeak-pronounce-dictionaries))
-(when (stringp key)
-(setq key (intern key )))
-(setf  (gethash key emacspeak-pronounce-dictionaries) pr-alist ))
+  (declare (special emacspeak-pronounce-dictionaries))
+  (when (stringp key)
+    (setq key (intern key )))
+  (setf  (gethash key emacspeak-pronounce-dictionaries) pr-alist ))
 
 (defsubst emacspeak-pronounce-get-dictionary (key)
-(declare (special emacspeak-pronounce-dictionaries))
-(when (stringp key)
-(setq key (intern key )))
-(cl-gethash key emacspeak-pronounce-dictionaries))
+  (declare (special emacspeak-pronounce-dictionaries))
+  (when (stringp key)
+    (setq key (intern key )))
+  (cl-gethash key emacspeak-pronounce-dictionaries))
 
 (defun emacspeak-pronounce-add-dictionary-entry  (key string pronunciation)
-  "Add pronunciation pair string.pronunciation to specified key in the
-pronunciation dictionary."
+  "Add dictionary entry.
+This adds pronunciation pair
+STRING.PRONUNCIATION to the   dictionary.
+Argument KEY specifies a dictionary key e.g. directory, mode etc."
   (declare (special emacspeak-pronounce-dictionaries ))
   (let ((dict  (emacspeak-pronounce-get-dictionary key)))
-    (cond 
-     (dict 
+    (cond
+     (dict
       (setf dict
             (cons (cons string pronunciation) dict))
       (emacspeak-pronounce-set-dictionary key dict ))
-     (t (emacspeak-pronounce-set-dictionary key 
+     (t (emacspeak-pronounce-set-dictionary key
                                             (list (cons string
                                                         pronunciation)))))))
 
 (defun emacspeak-pronounce-add-buffer-local-dictionary-entry  (string pronunciation)
-  "Adds specified pronunciation for current buffer"
-  (declare (special emacspeak-pronounce-pronunciation-table))
-  (cond 
+  "Add specified pronunciation for current buffer.
+Arguments STRING and PRONUNCIATION specify what is being defined."
+  (declare (special emacspeak-pronounce-pronunciation-table)) 
+  (cond
    ((not (boundp 'emacspeak-pronounce-pronunciation-table)) ;first time
     (set (make-local-variable 'emacspeak-pronounce-pronunciation-table)
          (emacspeak-pronounce-compose-pronunciation-table))
     (emacspeak-auditory-icon 'on))
    ( emacspeak-pronounce-pronunciation-table ;already on --
      (emacspeak-auditory-icon 'on))
-   (t                                   ;turn it on 
-    (setq emacspeak-pronounce-pronunciation-table 
+   (t                                   ;turn it on
+    (setq emacspeak-pronounce-pronunciation-table
           (emacspeak-pronounce-compose-pronunciation-table))))
-    (setf (gethash  (intern string) emacspeak-pronounce-pronunciation-table) pronunciation)
+  (setf (gethash  (intern string) emacspeak-pronounce-pronunciation-table) pronunciation)
   (message "Added  local pronunciation in buffer %s"
            (buffer-name)))
   
 ;;}}}
 ;;{{{ setting up inheritance relations
 
-;;; child inherits parents dictionary 
+;;; child inherits parents dictionary
 ;;; parent stored as a property on child symbol.
 ;;; when dictionary composed for a buffer, inherited dictionaries are
 ;;; also looked up.
 
 (defun emacspeak-pronounce-add-super  (parent child)
-  "Make child inherit parent's pronunciations"
+  "Make CHILD inherit PARENT's pronunciations."
   (let ((orig (get child 'emacspeak-pronounce-supers)))
     (unless (memq parent orig)
-    (setq orig
-          (nconc orig (list parent)))
-    (put child 'emacspeak-pronounce-supers orig ))
+      (setq orig
+            (nconc orig (list parent)))
+      (put child 'emacspeak-pronounce-supers orig ))
     orig))
 
 (defun emacspeak-pronounce-delete-super  (parent child)
-  "Stop  child inheriting  parent's pronunciations"
+  "Stop  child inheriting  PARENT's pronunciations."
   (let ((orig (get child 'emacspeak-pronounce-supers)))
     (when (memq parent orig)
-    (setq orig (delq parent  orig))
-    (put child 'emacspeak-pronounce-supers orig ))
+      (setq orig (delq parent  orig))
+      (put child 'emacspeak-pronounce-supers orig ))
     orig))
 
 (defun emacspeak-pronounce-compose-pronunciation-table  (&optional buffer)
-  "Composes a pronunciation table for buffer --default is current
-buffer. Handles inheritance of pronunciation dictionaries between
+  "Composes a pronunciation table for BUFFER.
+The default  is current
+buffer.  Handles inheritance of pronunciation dictionaries between
 modes."
   (setq buffer (or buffer (current-buffer )))
   (let* ((table (make-hash-table))
          (filename (buffer-file-name buffer))
-         (directory (and filename 
+         (directory (and filename
                          (file-name-directory  filename)))
-         (mode  (save-excursion 
+         (mode  (save-excursion
                   (set-buffer buffer)
                   major-mode))
          (mode-supers (emacspeak-pronounce-get-supers mode))
-         (file-alist (and filename 
+         (file-alist (and filename
                           (emacspeak-pronounce-get-dictionary filename)))
          (dir-alist (and directory
                          (emacspeak-pronounce-get-dictionary directory)))
@@ -162,26 +170,26 @@ modes."
           do
           (setq super-alist
                 (emacspeak-pronounce-get-dictionary super))
-          (loop for element in super-alist 
-                do 
+          (loop for element in super-alist
+                do
                 (setf (gethash
                        (intern (car element))
                        table)
                       (cdr element )))      )
-    (loop for element in mode-alist 
-          do 
+    (loop for element in mode-alist
+          do
           (setf (gethash
                  (intern (car element))
                  table)
                 (cdr element )))
-    (loop for element in dir-alist 
-          do 
+    (loop for element in dir-alist
+          do
           (setf (gethash
                  (intern (car element))
                  table)
                 (cdr element )))
-    (loop for element in file-alist 
-          do 
+    (loop for element in file-alist
+          do
           (setf (gethash
                  (intern (car element))
                  table)
@@ -209,7 +217,7 @@ modes."
 (emacspeak-pronounce-add-super 'text-mode 'latex2e-mode)
 (emacspeak-pronounce-add-super 'text-mode 'plain-tex-mode)
 
- ;;}}}
+;;}}}
 ;;{{{  Composing and applying dictionaries:
 
 ;;; Composing a dictionary results in the return of a hash table that
@@ -222,47 +230,48 @@ modes."
 ;;{{{  composing the dictionary
 
 (defun emacspeak-pronounce-get-supers (child)
-  "Return list of supers"
+  "Return list of supers.
+Argument CHILD  specifies the mode whose supers are being requested."
   (get child 'emacspeak-pronounce-supers))
 
 ;;}}}
 (defvar emacspeak-pronounce-pronunciation-personality
-nil
-"*Personality used when speaking  things that have a pronunciation
+  nil
+  "*Pronunciation personality.
+This is the personality used when speaking  things that have a pronunciation
 applied.")
 
 
 (defsubst emacspeak-pronounce-apply-pronunciations (pronunciation-table )
-  "Applies pronunciations specified in pronunciation table to current
-buffer. Modifies text in buffer. "
-  (save-match-data 
-    (save-excursion 
-      (loop for  key  being the hash-keys  of pronunciation-table  
-            do 
+  "Applies pronunciations specified in pronunciation table to current buffer.
+Modifies text in buffer."
+  (save-match-data
+    (save-excursion
+      (loop for  key  being the hash-keys  of pronunciation-table
+            do
             (let ((word (symbol-name key))
                   (pronunciation (cl-gethash  key pronunciation-table )))
               (goto-char (point-min))
               (while (search-forward  word nil t)
-                (replace-match  pronunciation nil t  )
+                (replace-match  pronunciation t t  )
                 (and emacspeak-pronounce-pronunciation-personality
-                     (put-text-property 
+                     (put-text-property
                       (match-beginning 0)
                       (+ (match-beginning 0) (length pronunciation))
-                      'personality 
+                      'personality
                       emacspeak-pronounce-pronunciation-personality))))))))
 
 ;;}}}
-;;{{{  loading, clearing  and saving dictionaries 
+;;{{{  loading, clearing  and saving dictionaries
 
-(defvar emacspeak-pronounce-dictionaries-file  nil 
-"File that holds the persistent emacspeak pronunciation
-dictionaries.")
+(defvar emacspeak-pronounce-dictionaries-file  nil
+  "File that holds the persistent emacspeak pronunciation dictionaries."
+  )
 
-
-  (declaim (special emacspeak-resource-directory))
-  (setq emacspeak-pronounce-dictionaries-file
-        (concat emacspeak-resource-directory "/"
-                ".dictionary"))
+(declaim (special emacspeak-resource-directory))
+(setq emacspeak-pronounce-dictionaries-file
+      (concat emacspeak-resource-directory "/"
+              ".dictionary"))
 
 
 (defun emacspeak-pronounce-save-dictionaries  ()
@@ -275,62 +284,63 @@ dictionaries.")
                    emacspeak-pronounce-dictionaries-file ))
         (buffer nil ))
     (setq buffer (find-file-noselect filename))
-    (save-excursion 
+    (save-excursion
       (set-buffer buffer)
       (erase-buffer)
       (loop for key being the hash-keys  of emacspeak-pronounce-dictionaries
             do
-            (insert 
+            (insert
              (format "(emacspeak-pronounce-set-dictionary '%S\n '%S )\n"
-                      key 
-                      (emacspeak-pronounce-get-dictionary key ))))
-(goto-char (point-min))
-(while (search-forward ")" nil t)
-(replace-match ")\n" nil t))
+                     key
+                     (emacspeak-pronounce-get-dictionary key ))))
+      (goto-char (point-min))
+      (while (search-forward ")" nil t)
+        (replace-match ")\n" nil t))
       (save-buffer))))
-(defvar emacspeak-pronounce-dictionaries-loaded nil 
-"Indicates if dictionaries already loaded.")
+(defvar emacspeak-pronounce-dictionaries-loaded nil
+  "Indicates if dictionaries already loaded.")
 
 (defun emacspeak-pronounce-load-dictionaries  (&optional filename)
-  "Load pronunciation dictionaries"
+  "Load pronunciation dictionaries.
+Optional argument FILENAME specifies the dictionary file."
   (interactive
    (list (read-file-name
-                   "Load pronunciation dictionaries from file: "
-                   default-directory
-                   emacspeak-pronounce-dictionaries-file )))
-(declare (special emacspeak-pronounce-dictionaries-loaded))
-    (load-file filename)
-(setq emacspeak-pronounce-dictionaries-loaded t))
+          "Load pronunciation dictionaries from file: "
+          default-directory
+          emacspeak-pronounce-dictionaries-file )))
+  (declare (special emacspeak-pronounce-dictionaries-loaded))
+  (load-file filename)
+  (setq emacspeak-pronounce-dictionaries-loaded t))
 
 (defun emacspeak-pronounce-clear-dictionaries ()
-"Clear all current pronunciation dictionaries."
-(interactive)
-(declare (special emacspeak-pronounce-dictionaries ))
-(when (yes-or-no-p 
-"Do you really want to nuke all currently defined dictionaries?")
-(setq emacspeak-pronounce-dictionaries
-(make-hash-table ))
-(emacspeak-pronounce-refresh-pronunciations)))
+  "Clear all current pronunciation dictionaries."
+  (interactive)
+  (declare (special emacspeak-pronounce-dictionaries ))
+  (when (yes-or-no-p
+         "Do you really want to nuke all currently defined dictionaries?")
+    (setq emacspeak-pronounce-dictionaries
+          (make-hash-table ))
+    (emacspeak-pronounce-refresh-pronunciations)))
 
 ;;}}}
 ;;{{{  Front end to define pronunciations:
 
-(defvar emacspeak-pronounce-pronunciation-keys 
-'(("buffer" . "buffer")
-  ("file" . "file")
-("directory" . "directory")
-("mode" . "mode"))
-"Pronunciations can be defined for these kinds of things. ")
+(defvar emacspeak-pronounce-pronunciation-keys
+  '(("buffer" . "buffer")
+    ("file" . "file")
+    ("directory" . "directory")
+    ("mode" . "mode"))
+  "Pronunciations can be defined for these kinds of things.")
 
 (defvar emacspeak-pronounce-current-buffer nil
-  "Buffer name where we are currently defining a pronunciation")
+  "Buffer name where we are currently defining a pronunciation.")
 
 (defvar emacspeak-pronounce-yank-word-point nil
-  "Point where we left off reading from the buffer containing the term
-being defined")
+  "Point where we left off reading from the buffer containing the term being defined.")
 
 (make-variable-buffer-local ' emacspeak-pronounce-yank-word-point)
 (defsubst emacspeak-pronounce-yank-word ()
+  "Yank word at point into minibuffer."
   (interactive)
   (declare (special emacspeak-pronounce-yank-word-point
                     emacspeak-pronounce-current-buffer))
@@ -364,19 +374,20 @@ being defined")
        now-map))))
 
 (defun emacspeak-pronounce-define-local-pronunciation (word  pronunciation )
-  "Define buffer local pronounciation. "
+  "Define buffer local pronounciation.
+Argument WORD specifies the word which should be pronounced as specified by PRONUNCIATION."
   (interactive
    (list
     (emacspeak-pronounce-read-term 'buffer)
     (read-from-minibuffer
-           (format "Pronounce  as: " ))))
+     (format "Pronounce  as: " ))))
   (emacspeak-pronounce-add-buffer-local-dictionary-entry
    word pronunciation))
 
 (defun emacspeak-pronounce-define-pronunciation ()
   "Interactively define entries in the pronunciation dictionaries.
 Default term to define is delimited by region.
-First loads any persistent dictionaries if not already loaded. "
+First loads any persistent dictionaries if not already loaded."
   (interactive)
   (declare (special emacspeak-pronounce-dictionaries-loaded))
   (let ((key nil)
@@ -389,13 +400,13 @@ First loads any persistent dictionaries if not already loaded. "
       (setq key (buffer-name )))        ;handled differently
      ((string= key-type "file")
       (setq key (buffer-file-name))
-      (or key 
-          (error "Current buffer is not associated with a file."))
+      (or key
+          (error "Current buffer is not associated with a file"))
       (setq key (intern key)))
      ((string= key-type "directory")
-      (setq key 
+      (setq key
             (or
-             (condition-case nil 
+             (condition-case nil
                  (file-name-directory (buffer-file-name ))
                (error nil ))
              default-directory))
@@ -407,15 +418,15 @@ First loads any persistent dictionaries if not already loaded. "
       (or key (error "No major mode found for current buffer")))
      (t (error "Cannot define pronunciations with key type %s" key-type)))
     (setq word (emacspeak-pronounce-read-term key))
-    (setq pronunciation 
+    (setq pronunciation
           (read-from-minibuffer
            (format "Pronounce %s as: " word)))
     (when (and (not emacspeak-pronounce-dictionaries-loaded)
-               (y-or-n-p "Load pre existing  pronunciation dictionaries first"))
+               (y-or-n-p "Load pre existing  pronunciation dictionaries first? "))
       (emacspeak-pronounce-load-dictionaries))
     (unless  (string= key-type  "buffer")
       (emacspeak-pronounce-add-dictionary-entry key word pronunciation)
-        (funcall 'emacspeak-pronounce-refresh-pronunciations))
+      (funcall 'emacspeak-pronounce-refresh-pronunciations))
     (when (string= key-type  "buffer")
       (emacspeak-pronounce-add-buffer-local-dictionary-entry  word pronunciation))))
 
@@ -429,8 +440,8 @@ Becomes automatically buffer local.")
 (make-variable-buffer-local 'emacspeak-pronounce-pronunciation-table)
 (setq-default emacspeak-pronounce-pronunciation-table nil)
 
-(defun emacspeak-pronounce-toggle-use-of-dictionaries ()
-  "Toggles use of pronunciation dictionaries in current buffer.
+(defun emacspeak-pronounce-toggle-use-of-dictionaries (&optional state)
+  "Toggle use of pronunciation dictionaries in current buffer.
 Pronunciations can be dfined on a per file, per directory and/or per
 mode basis.
 Pronunciations are activated on a per buffer basis.
@@ -438,27 +449,31 @@ Turning on the use of pronunciation dictionaries results in emacspeak
 composing a pronunciation table based on the currently defined
 pronunciation dictionaries.
 After this, the pronunciations will be applied whenever text in the
-buffer is spoken."
+buffer is spoken.
+Optional argument state can be used from Lisp programs to
+explicitly turn pronunciations on or off."
   (interactive)
   (declare (special emacspeak-pronounce-pronunciation-table))
-  (cond 
-   ((not (boundp 'emacspeak-pronounce-pronunciation-table)) ;first time
-     (make-local-variable 'emacspeak-pronounce-pronunciation-table)
-         (setq emacspeak-pronounce-pronunciation-table
+  (cond
+   ((or (eq state 'on)
+        (not (boundp 'emacspeak-pronounce-pronunciation-table)))
+    (make-local-variable 'emacspeak-pronounce-pronunciation-table)
+    (setq emacspeak-pronounce-pronunciation-table
           (emacspeak-pronounce-compose-pronunciation-table))
     (emacspeak-auditory-icon 'on)
+    (message "Emacspeak pronunciation dictionaries are now active in this buffer"))
+   ((or (eq state 'off)
+                                        ;already on --turn it off
+        emacspeak-pronounce-pronunciation-table )
+    (setq emacspeak-pronounce-pronunciation-table nil)
+    (emacspeak-auditory-icon 'off)
     (message
-     "Emacspeak pronunciation dictionaries are now active in this buffer"))
-   ( emacspeak-pronounce-pronunciation-table ;already on --turn it off
-     (setq emacspeak-pronounce-pronunciation-table nil)
-     (emacspeak-auditory-icon 'off)
-     (message
- "Emacspeak pronunciation dictionaries no longer active in this buffer"))
-   (t                                   ;turn it on 
-    (setq emacspeak-pronounce-pronunciation-table 
+     "Emacspeak pronunciation dictionaries no longer active in this buffer"))
+   (t                                   ;turn it on
+    (setq emacspeak-pronounce-pronunciation-table
           (emacspeak-pronounce-compose-pronunciation-table))
     (message
- "Emacspeak pronunciations have been re-activated in this buffer")
+     "Emacspeak pronunciations have been re-activated in this buffer")
     (emacspeak-auditory-icon 'on))))
 
 (defun emacspeak-pronounce-refresh-pronunciations ()
@@ -466,21 +481,21 @@ buffer is spoken."
 Activates pronunciation dictionaries if not already active."
   (interactive)
   (declare (special emacspeak-pronounce-pronunciation-table))
-  (cond 
+  (cond
    ((not (boundp 'emacspeak-pronounce-pronunciation-table)) ;first time
     (set (make-local-variable 'emacspeak-pronounce-pronunciation-table)
          (emacspeak-pronounce-compose-pronunciation-table))
     (emacspeak-auditory-icon 'on)
     (message
      "Refreshed pronunciations for this buffer"))
-   ( emacspeak-pronounce-pronunciation-table ;already on --refresh it 
+   ( emacspeak-pronounce-pronunciation-table ;already on --refresh it
      (setq emacspeak-pronounce-pronunciation-table
            (emacspeak-pronounce-compose-pronunciation-table))
      (emacspeak-auditory-icon 'on)
      (message
       "Refreshed pronunciation for this buffer"))
-   (t                                   ;turn it on 
-    (setq emacspeak-pronounce-pronunciation-table 
+   (t                                   ;turn it on
+    (setq emacspeak-pronounce-pronunciation-table
           (emacspeak-pronounce-compose-pronunciation-table))
     (message
      "Refreshed pronunciations for this buffer")
@@ -489,9 +504,9 @@ Activates pronunciation dictionaries if not already active."
 ;;}}}
 ;;{{{ top level dispatch routine
 
-(defvar emacspeak-pronounce-help 
-"Dictionary:  Clear Define Load Refresh Save Toggle"
-"Help message listing emacspeak commands")
+(defvar emacspeak-pronounce-help
+  "Dictionary:  Clear Define Load Refresh Save Toggle"
+  "Help message listing emacspeak commands.")
 
 (defun emacspeak-pronounce-dispatch ()
   "Provides the user interface front-end to Emacspeak's pronunciation dictionaries."
@@ -499,7 +514,7 @@ Activates pronunciation dictionaries if not already active."
   (declare (special emacspeak-pronounce-help))
   (message emacspeak-pronounce-help)
   (let ((event (read-event)))
-    (case event 
+    (case event
       (?c (call-interactively 'emacspeak-pronounce-clear-dictionaries))
       (?d (call-interactively
            'emacspeak-pronounce-define-pronunciation t))
@@ -512,11 +527,11 @@ Activates pronunciation dictionaries if not already active."
 
 ;;}}}
 (provide  'emacspeak-pronounce)
-;;{{{  emacs local variables 
+;;{{{  emacs local variables
 
 ;;; local variables:
 ;;; folded-file: t
 ;;; byte-compile-dynamic: nil
-;;; end: 
+;;; end:
 
 ;;}}}
