@@ -1,22 +1,22 @@
 ;;; emacspeak-realaudio.el --- Play realaudio from Emacs
-;;; $Id: emacspeak-realaudio.el,v 9.0 1998/10/24 05:17:28 raman Exp $
+;;; $Id: emacspeak-realaudio.el,v 11.0 1999/11/29 16:58:57 raman Exp $
 ;;; $Author: raman $
 ;;; Description: Single click access to RealAudio from emacspeak
 ;;; Keywords: Emacspeak, RealAudio
 ;;{{{  LCD Archive entry: 
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@adobe.com 
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/10/24 05:17:28 $ |
-;;;  $Revision: 9.0 $ | 
+;;; $Date: 1999/11/29 16:58:57 $ |
+;;;  $Revision: 11.0 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1997 by T. V. Raman Adobe Systems Incorporated 
+;;; Copyright (c) 1997 by T. V. Raman  
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -45,6 +45,7 @@
 (eval-when (compile)
   (require 'emacspeak-fix-interactive))
 (require 'emacspeak-sounds)
+(require 'thingatpt)
 ;;}}}
 ;;{{{ Introduction:
 
@@ -111,12 +112,16 @@ emacspeak-realaudio-shortcuts-directory"
      ""                                 ;initial content
      'emacspeak-realaudio-history
      emacspeak-realaudio-last-url))))
-  (declare (special emacspeak-realaudio-player emacspeak-realaudio-process
+  (declare (special emacspeak-realaudio-player
+                    emacspeak-use-midi-icons
+                    emacspeak-realaudio-process
+emacspeak-realaudio-start-time
+emacspeak-realaudio-mark-time
                     emacspeak-realaudio-shortcuts-directory
                     emacspeak-realaudio-history
                     emacspeak-use-auditory-icons))
   (unless (string= resource (car emacspeak-realaudio-history))
-    (push resource emacspeak-realaudio-history))
+    (pushnew resource emacspeak-realaudio-history))
   (when (and emacspeak-realaudio-process
              (eq 'run (process-status emacspeak-realaudio-process)))
     (kill-process emacspeak-realaudio-process))
@@ -124,21 +129,29 @@ emacspeak-realaudio-shortcuts-directory"
         (start-process"realaudio" " realaudio"
                       emacspeak-realaudio-player
                       resource ))
+  (setq emacspeak-realaudio-start-time (current-time))
   (unless (eq 'run (process-status
                     emacspeak-realaudio-process))
     (message "Failed to start RealAudio"))
   (message "Playing  Realaudio stream %s" resource)
   (setq emacspeak-realaudio-last-url resource)
   (when emacspeak-use-auditory-icons
-(emacspeak-toggle-auditory-icons t)))
+    (unless emacspeak-use-midi-icons
+(emacspeak-toggle-midi-icons))))
 
+(defvar emacspeak-realaudio-dont-insist-on-ram-url t
+  "*Set to nil if you want emacspeak to insist that realaudio
+urls have a .ram or .rm extension.")
 
 (defun emacspeak-realaudio-play-url-at-point ()
   "Play url under point as realaudio"
   (interactive)
+  (declare (special emacspeak-realaudio-dont-insist-on-ram-url))
   (let ((url (w3-view-this-url 'no-show)))
     (cond
-     ((string-match ".ram?$" url)
+     ((or emacspeak-realaudio-dont-insist-on-ram-url
+       (string-match ".rm?$" url)
+       (string-match ".ram?$" url))
       (message "Playing Realaudio URL under point")
         (emacspeak-realaudio-play url))
       (t (message "%s does not look like realaudio"
@@ -147,12 +160,26 @@ emacspeak-realaudio-shortcuts-directory"
 (defun emacspeak-realaudio-stop ()
   "Stop playing realaudio"
   (interactive)
-  (declare (special emacspeak-realaudio-process))
+  (declare (special emacspeak-realaudio-process
+                    emacspeak-realaudio-stop-time))
   (kill-process emacspeak-realaudio-process)
+(setq emacspeak-realaudio-stop-time (current-time))
   (message "Stopped RealAudio")
   (emacspeak-toggle-auditory-icons t))
 
-(defun emacspeak-realaudio  ()
+(defvar emacspeak-realaudio-start-time nil
+  "Records  time when we started playing.
+Used to track how long into a stream we've played.")
+
+(defvar emacspeak-realaudio-stop-time nil
+"Records time stamp when we stopped playing.")
+
+(defvar emacspeak-realaudio-mark-time nil
+"Records where to resume playing if streaming is stopped for
+some reason.")
+
+
+(defun emacspeak-realaudio  (&optional resume)
   "Start or stop playing RealAudio.  Stops playing realaudio
 if there is a stream currently playing.  Otherwise, prompts
 for a realaudio resource.  Realaudio resources can be
@@ -164,8 +191,9 @@ default is to play the resource you played most
 recently. Emacspeak uses the contents of the directory
 specified by variable
 emacspeak-realaudio-shortcuts-directory to offer a set of
-completions. Hit tab to use this completion list."
-  (interactive)
+completions. Hit tab to use this completion list.  Optional
+interactive prefix arg prompts for time stamp at which to resume."
+  (interactive "P")
   (declare (special emacspeak-realaudio-process))
   (cond
    ((and emacspeak-realaudio-process
@@ -173,6 +201,61 @@ completions. Hit tab to use this completion list."
     (emacspeak-realaudio-stop))
    (t  (call-interactively 'emacspeak-realaudio-play))))
 
+;;}}}
+;;{{{ browsing ramfiles
+
+
+(defun emacspeak-realaudio-parse-ramfile(ramfile)
+  "Returns a list of strings."
+  (let ((buff (find-file-noselect ramfile))
+(result nil))
+(save-excursion
+  (set-buffer buff)
+(while (not (eobp))
+(push (thing-at-point 'line)  result)
+(forward-line 1)))
+(kill-buffer buff)
+result))
+
+(defun emacspeak-realaudio-browse (ramfile &optional start-time)
+  "Browse RAM file before playing the selected component."
+  (interactive
+   (list
+    (let ((completion-ignore-case t))
+      (completing-read
+       "Realaudio Resource:"
+       (loop for f in
+             (cddr (directory-files  emacspeak-realaudio-shortcuts-directory t))
+             collect (cons f f ))
+       nil
+       nil
+       ""                               ;initial content
+       'emacspeak-realaudio-history
+       emacspeak-realaudio-last-url))
+    current-prefix-arg))
+  (let ((components (emacspeak-realaudio-parse-ramfile
+                     ramfile))
+        (component nil)
+        (option nil)
+        (s nil))
+    (setq component 
+          (completing-read
+           "Realaudio component:"
+           (loop for f in
+                 components
+                 collect (cons f f ))))
+    (when(and  (interactive-p)
+               start-time)
+      (setq s (read-string "Minutes to skip: "))
+      (setq option 
+            (if (string-match "?" component)
+                (format "&start=00:00:%s:00.0" s)
+              (format "?start=00:00:%s:00.0" s)))
+      (setq component
+            (concat component option )))
+    (emacspeak-realaudio-play  component)))
+     
+
 ;;}}}
 ;;{{{ W3 hook
 
