@@ -1,22 +1,22 @@
 ;;; emacspeak-remote.el --- Enables running remote Emacspeak sessions
-;;; $Id: emacspeak-remote.el,v 8.0 1998/05/01 14:15:46 raman Exp $
+;;; $Id: emacspeak-remote.el,v 11.0 1999/11/29 16:58:57 raman Exp $
 ;;; $Author: raman $ 
 ;;; Description: Auditory interface to remote speech server
 ;;; Keywords: Emacspeak, Speak, Spoken Output, remote server
 ;;{{{  LCD Archive entry: 
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@adobe.com 
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/05/01 14:15:46 $ |
-;;;  $Revision: 8.0 $ | 
+;;; $Date: 1999/11/29 16:58:57 $ |
+;;;  $Revision: 11.0 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1997 by T. V. Raman Adobe Systems Incorporated 
+;;; Copyright (c) 1997 by T. V. Raman  
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -120,7 +120,9 @@ a local  Emacspeak terminal buffer.")
           (result nil))
       (save-excursion
         (set-buffer buffer)
-        (setq result (buffer-string )))
+        (setq result (buffer-substring
+                      (point-min)
+                      (1- (point-max)))))
       (kill-buffer buffer )
       result)))
 
@@ -184,8 +186,10 @@ host is listening on for speech requests."
             (format "%s" port ))
       (delete-process old-process)
       (run-hooks 'emacspeak-remote-hooks)
+      (sit-for 5)
       (message "Connecting to server on host %s  port %s"
-               host port ))
+               host port )
+      (sit-for 5))
      (t (error "Failed to connect to speech server on host %s port %s"
                host port )))))
 
@@ -204,6 +208,7 @@ host is listening on for speech requests."
 
 ;;; local variables:
 ;;; folded-file: t
+;;; byte-compile-dynamic: t
 ;;; end: 
 
 ;;}}}
