@@ -1,21 +1,21 @@
 ;;; emacspeak-replace.el --- Speech enable interactive search and replace
-;;; $Id: emacspeak-replace.el,v 9.0 1998/10/24 05:17:28 raman Exp $
+;;; $Id: emacspeak-replace.el,v 11.0 1999/11/29 16:58:57 raman Exp $
 ;;; $Author: raman $ 
 ;;; Description:  Emacspeak extension for replace.el
 ;;; Keywords: Emacspeak, Speech feedback, query replace (replace.el)
 ;;{{{  LCD Archive entry: 
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@adobe.com 
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/10/24 05:17:28 $ |
-;;;  $Revision: 9.0 $ | 
+;;; $Date: 1999/11/29 16:58:57 $ |
+;;;  $Revision: 11.0 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995, 1996, 1997, 1998   T. V. Raman  Adobe Systems Incorporated
+;;;Copyright (C) 1995, 1996, 1997, 1998, 1999   T. V. Raman  
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -53,8 +53,10 @@
 ;;}}}
 ;;{{{  define personalities
 
-(dtk-define-voice 'emacspeak-replace-personality
-                  "[:np :dv ap 142]" )
+(defvar emacspeak-replace-personality
+                  'paul-animated
+                  "Personality to indicate word that is
+being replaced.")
 
 ;;}}}
 ;;{{{  Advice
@@ -110,7 +112,7 @@
                   (get-text-property  from 'personality))
             (and from to 
                  (put-text-property from to 'personality
-                                    'emacspeak-replace-personality ))
+                                    emacspeak-replace-personality ))
             (dtk-stop)
             (emacspeak-speak-line))
         (error nil )))))
