@@ -1,22 +1,22 @@
 ;;; emacspeak-speedbar.el --- Speech enable speedbar -- Tool for context-sensitive navigation
-;;; $Id: emacspeak-speedbar.el,v 9.0 1998/10/24 05:17:28 raman Exp $
+;;; $Id: emacspeak-speedbar.el,v 11.0 1999/11/29 16:58:57 raman Exp $
 ;;; $Author: raman $ 
 ;;; Description: Auditory interface to speedbar
 ;;; Keywords: Emacspeak, Speedbar
 ;;{{{  LCD Archive entry: 
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@adobe.com 
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/10/24 05:17:28 $ |
-;;;  $Revision: 9.0 $ | 
+;;; $Date: 1999/11/29 16:58:57 $ |
+;;;  $Revision: 11.0 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1997 by T. V. Raman Adobe Systems Incorporated 
+;;; Copyright (c) 1997 by T. V. Raman  
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -239,11 +239,6 @@ An automatically updating speedbar consumes resources.")
              )
      (t (message "No target on this line")))))
 
-;;}}}
-;;{{{ keybindings
-
-(global-set-key '[insert] 'emacspeak-speedbar-goto-speedbar)
-
 ;;}}}
 ;;{{{  hooks
 (declaim (special speedbar-key-map))
@@ -317,6 +312,12 @@ An automatically updating speedbar consumes resources.")
       (save-match-data
         (beginning-of-line)))))
 
+;;}}}
+;;{{{ keys 
+(declaim (special emacspeak-keymap))
+
+(define-key emacspeak-keymap '[insert] 'emacspeak-speedbar-goto-speedbar)
+
 ;;}}}
 (provide 'emacspeak-speedbar)
 ;;{{{ end of file 
