@@ -1,22 +1,22 @@
 ;;; emacspeak-table-ui.el --- Emacspeak's current notion of an ideal table UI
-;;; $Id: emacspeak-table-ui.el,v 9.0 1998/10/24 05:17:28 raman Exp $
+;;; $Id: emacspeak-table-ui.el,v 11.0 1999/11/29 16:58:57 raman Exp $
 ;;; $Author: raman $ 
 ;;; Description: Emacspeak table handling module
 ;;; Keywords:emacspeak, audio interface to emacs tables are structured
 ;;{{{  LCD Archive entry: 
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@adobe.com
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/10/24 05:17:28 $ |
-;;;  $Revision: 9.0 $ | 
+;;; $Date: 1999/11/29 16:58:57 $ |
+;;;  $Revision: 11.0 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995, 1996, 1997, 1998   T. V. Raman  Adobe Systems Incorporated
-;;; Copyright (c) 1995 by T. V. Raman Adobe Systems Incorporated 
+;;;Copyright (C) 1995, 1996, 1997, 1998, 1999   T. V. Raman  
+;;; Copyright (c) 1995 by T. V. Raman  
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -65,7 +65,9 @@
   "Keymap for using in table browsing mode")
 
 (progn
-  (define-key emacspeak-table-keymap "q" 'emacspeak-kill-buffer-quietly)
+  (define-key emacspeak-table-keymap "q"
+    'emacspeak-kill-buffer-quietly)
+  (define-key emacspeak-table-keymap "x" 'emacspeak-table-copy-current-element-to-register)
   (define-key emacspeak-table-keymap "\t"
     'emacspeak-table-next-column)
   (define-key emacspeak-table-keymap  '[S-tab] 'emacspeak-table-previous-column)
@@ -80,6 +82,7 @@
   (define-key emacspeak-table-keymap "b"
     'emacspeak-table-speak-both-headers-and-element)
 (define-key emacspeak-table-keymap "." 'emacspeak-table-speak-coordinates)
+(define-key emacspeak-table-keymap "=" 'emacspeak-table-speak-dimensions)
 (define-key emacspeak-table-keymap "a"
   'emacspeak-table-select-automatic-speaking-method)
 (define-key emacspeak-table-keymap "s" 'emacspeak-table-search)
@@ -166,12 +169,20 @@ having 8 columns, a row filter of ( 1 2 3) will speak only entries 1 2 and 3.
 Use the sample table matrix.dat to familiarize yourself with this
 feature. Note that you can intersperse meaningful strings in the list that
 specifies the filter"
-(declare (special emacspeak-table-keymap)) (use-local-map
-emacspeak-table-keymap) (set (make-local-variable 'voice-lock-mode) t) (setq
-major-mode 'emacspeak-table-mode) (setq mode-name "table") (put-text-property
-(point-min) (point-max) 'point-entered 'emacspeak-table-point-motion-hook)
-(not-modified) (setq buffer-read-only t) (emacspeak-auditory-icon 'alarm)
-(emacspeak-speak-mode-line))
+  (declare (special emacspeak-table-keymap))
+  (use-local-map emacspeak-table-keymap)
+  (set (make-local-variable 'voice-lock-mode) t)
+  (setq major-mode 'emacspeak-table-mode
+        mode-name "table")
+  (put-text-property
+   (point-min)
+   (point-max)
+   'point-entered
+   'emacspeak-table-point-motion-hook)
+  (not-modified)
+  (setq buffer-read-only t)
+  (emacspeak-auditory-icon 'select-object)
+  (emacspeak-speak-mode-line))
 
 ;;}}}
 ;;{{{  speaking current entry 
@@ -203,7 +214,17 @@ major-mode 'emacspeak-table-mode) (setq mode-name "table") (put-text-property
   (and (boundp 'emacspeak-table)
        (message "Row %s Column %s"
                 (emacspeak-table-current-row emacspeak-table)
-                (emacspeak-table-current-column emacspeak-table))))
+                (emacspeak-table-current-column
+                 emacspeak-table))))
+
+(defsubst  emacspeak-table-speak-dimensions ()
+  "Speak current table dimensions."
+  (interactive)
+  (declare (special emacspeak-table))
+  (and (boundp 'emacspeak-table)
+       (message "%s by %s table"
+                (emacspeak-table-num-rows emacspeak-table)
+                (emacspeak-table-num-columns emacspeak-table))))
 
 (defun emacspeak-table-speak-current-element ()
   "Speak current table element"
@@ -749,6 +770,14 @@ match, makes the matching row or column current."
 ;;}}}
 ;;{{{ cutting and pasting tables:
 
+(defun emacspeak-table-copy-current-element-to-register (register)
+  "Speak current table element"
+  (interactive "cCopy to register: ")
+  (declare (special emacspeak-table ))
+  (and (boundp 'emacspeak-table)
+       (set-register register 
+ (emacspeak-table-current-element emacspeak-table))))
+(emacspeak-fix-interactive-command-if-necessary 'emacspeak-table-copy-current-element-to-register)
 ;;; Implementing table editing and table clipboard.
 ;;{{{ variables 
 
