@@ -1,21 +1,21 @@
 ;;; emacspeak-view.el --- Speech enable View mode -- Efficient browsing of read-only content
-;;; $Id: emacspeak-view.el,v 9.0 1998/10/24 05:17:28 raman Exp $
+;;; $Id: emacspeak-view.el,v 11.0 1999/11/29 16:58:57 raman Exp $
 ;;; $Author: raman $ 
 ;;; DescriptionEmacspeak extensions for view
 ;;; Keywords:emacspeak, audio interface to emacs, view-mode
 ;;{{{  LCD Archive entry: 
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@adobe.com
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/10/24 05:17:28 $ |
-;;;  $Revision: 9.0 $ | 
+;;; $Date: 1999/11/29 16:58:57 $ |
+;;;  $Revision: 11.0 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995, 1996, 1997, 1998   T. V. Raman  Adobe Systems Incorporated
+;;;Copyright (C) 1995, 1996, 1997, 1998, 1999   T. V. Raman  
 ;;; Copyright (c) 1996 by T. V. Raman 
 ;;; All Rights Reserved. 
 ;;;
@@ -78,6 +78,9 @@ View-search-regexp-forward))
 
 ;;}}}
 ;;{{{ Advise additional interactive commands:
+(defadvice view-file (after emacspeak pre act comp)
+  "Load directory specific settings"
+(emacspeak-speak-load-directory-settings))
 (defadvice view-mode (after emacspeak pre act comp)
   "Announce what happened"
   (when (interactive-p)
@@ -324,7 +327,9 @@ keybindings for view mode")
           (format "%s" i)
           'emacspeak-speak-predefined-window))
 ;;;convenience keys
-  (define-key view-mode-map "\C-j" 'emacspeak-hide-speak-block-sans-prefix)
+  (define-key view-mode-map "\C-j"
+    'emacspeak-hide-speak-block-sans-prefix)
+  (define-key view-mode-map "\M- " 'emacspeak-outline-speak-this-heading)
   (define-key view-mode-map "\M-n"
     'outline-next-visible-heading)
   (define-key view-mode-map "\M-p" 'outline-previous-visible-heading)
