@@ -1,21 +1,21 @@
 ;;; emacspeak-w3.el --- Speech enable W3 WWW browser -- includes ACSS Support
-;;; $Id: emacspeak-w3.el,v 9.0 1998/10/24 05:17:28 raman Exp $
+;;; $Id: emacspeak-w3.el,v 11.0 1999/11/29 16:58:57 raman Exp $
 ;;; $Author: raman $ 
 ;;; Description:  Emacspeak enhancements for W3
 ;;; Keywords: Emacspeak, W3, WWW
 ;;{{{  LCD Archive entry: 
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@adobe.com 
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/10/24 05:17:28 $ |
-;;;  $Revision: 9.0 $ | 
+;;; $Date: 1999/11/29 16:58:57 $ |
+;;;  $Revision: 11.0 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995, 1996, 1997, 1998   T. V. Raman  Adobe Systems Incorporated
+;;;Copyright (C) 1995, 1996, 1997, 1998, 1999   T. V. Raman  
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -73,7 +73,9 @@
 (condition-case nil
     (progn (require 'w3-speak)
            (add-hook 'w3-mode-hook 'w3-speak-mode-hook)
-           (setq w3-echo-link 'text)
+(add-hook 'w3-mode-hook 'emacspeak-pronounce-toggle-use-of-dictionaries)
+(setq w3-echo-link
+                 (list 'text 'title 'name 'url))
            (if (locate-library "w3-speak-table")
              (load-library "w3-speak-table")
              (message
@@ -93,8 +95,13 @@ that is no longer supported by Emacspeak.")))
  (function
   (lambda ()
     (modify-syntax-entry 10 " ")
+    (define-key w3-mode-map ";" 'emacspeak-w3-speak-this-element)
+    (define-key w3-mode-map "n"
+      'emacspeak-w3-next-doc-element)
+    (define-key w3-mode-map "p" 'emacspeak-w3-previous-doc-element)
     (define-key w3-mode-map "L"
       'emacspeak-w3-lynx-url-under-point)
+    (define-key w3-mode-map "\C-f" 'w3-table-focus-on-this-cell)
     (define-key w3-mode-map  "\C-t" 'emacspeak-w3-toggle-table-borders)
     (define-key w3-mode-map "'" 'emacspeak-speak-rest-of-buffer)
     (define-key w3-mode-map "j" 'imenu)
@@ -114,19 +121,21 @@ that is no longer supported by Emacspeak.")))
 ;;{{{ fix interactive commands
 
 (loop for f in
-      '(url-insert-file-contents
-w3-hotlist-apropos
-w3-open-local
-w3-read-html-bookmarks
-w3-search-forward
-w3-find-file
-w3-follow-url-at-point
-w3-follow-url-at-point-other-frame
-w3-hotlist-append
-w3-hotlist-apropos
-w3-read-html-bookmarks)
+      (list 'url-insert-file-contents
+'w3-open-local
+'w3-read-html-bookmarks
+'w3-search-forward
+'w3-find-file
+'w3-follow-url-at-point
+'w3-follow-url-at-point-other-frame
+'w3-read-html-bookmarks)
       do
       (emacspeak-fix-interactive-command-if-necessary f ))
+(eval-when (load eval)
+(eval-after-load  "w3-hot"
+  (progn
+    (emacspeak-fix-interactive-command-if-necessary 'w3-hotlist-apropos)
+(emacspeak-fix-interactive-command-if-necessary 'w3-hotlist-append))))
 
 ;;}}}
 ;;{{{  dump using lynx 
@@ -232,6 +241,132 @@ t
            (if emacspeak-w3-table-draw-border "" "not")))
 
 
+;;}}}
+;;{{{ Experimental --element navigation
+
+;;;This should eventually be done via a DOM API
+
+
+(defsubst emacspeak-w3-html-stack () (get-text-property (point) 'html-stack))
+
+(defsubst emacspeak-w3-html-stack-top-element (&optional stack)
+  (or stack (setq stack (emacspeak-w3-html-stack)))
+  (first (first stack )))
+
+(defun emacspeak-w3-next-doc-element (&optional count)
+  "Move forward  to the next document element.
+Optional interactive prefix argument COUNT 
+specifies by how many eleemnts to move."
+  (interactive "P")
+  (cond
+   ((null count)
+    (goto-char
+     (next-single-property-change (point)
+                                  'html-stack
+                                  (current-buffer)
+                                  (point-max)))
+    (unless (emacspeak-w3-html-stack)
+                                        ;skip over null region
+      (goto-char
+       (next-single-property-change (point)
+                                    'html-stack
+                                    (current-buffer)
+                                    (point-max)))))
+   (t (message "Moving by more than 1 not yet
+implemented. ")))
+  (let ((emacspeak-show-point t))
+    (emacspeak-w3-speak-next-element)))
+
+(defun emacspeak-w3-previous-doc-element (&optional count)
+  "Move back  to the previous document element.
+Optional interactive prefix argument COUNT 
+specifies by how many eleemnts to move."
+  (interactive "P")
+  (cond
+   ((null count)
+    (unless (emacspeak-w3-html-stack)
+      ;skip over null region
+      (goto-char
+                  (previous-single-property-change (point)
+                                               'html-stack
+                                               (current-buffer)
+                                               (point-min))))
+    (goto-char
+                  (previous-single-property-change (point)
+                                               'html-stack
+                                               (current-buffer)
+                                               (point-min))))
+   (t (message "Moving by more than 1 not yet
+implemented. ")))
+  (let ((emacspeak-show-point t))
+    (emacspeak-w3-speak-this-element)))
+
+
+(defun emacspeak-w3-speak-this-element ()
+  "Speak document element under point."
+  (interactive)
+  (let ((start nil)
+        (end nil))
+    (save-excursion
+      (goto-char (previous-single-property-change (point)
+                                                  'html-stack
+                                                  (current-buffer)
+                                                  (point-min)))
+      (setq start (point))
+      (goto-char (next-single-property-change (point)
+                                              'html-stack
+                                              (current-buffer)
+                                              (point-max)))
+      (setq end (point))
+      (emacspeak-speak-region start end )
+      (emacspeak-auditory-icon 'select-object))))
+
+
+(defun emacspeak-w3-speak-next-element ()
+  "Speak next document element."
+  (interactive)
+  (let ((start (point))
+        (end nil))
+    (save-excursion
+      
+      (goto-char (next-single-property-change (point)
+                                              'html-stack
+                                              (current-buffer)
+                                              (point-max)))
+      (setq end (point))
+      (emacspeak-speak-region start end )
+      (emacspeak-auditory-icon 'select-object))))
+;;}}}
+;;{{{ experimental --unravel javascript urls 
+(defvar emacspeak-w3-javascript-cleanup-buffer " *javascript-cleanup*"
+  "temporary scratch area")
+
+(defun emacspeak-w3-javascript-follow-link ()
+  "Follow URL hidden inside a javascript link"
+  (interactive)
+  (unless (eq major-mode 'w3-mode)
+    (error "Not in a W3 buffer."))
+  (let ((url (w3-view-this-url 'no-show))
+        (buffer (get-buffer-create
+                emacspeak-w3-javascript-cleanup-buffer)))
+    (save-excursion
+      (set-buffer buffer)
+      (erase-buffer)
+      (insert url)
+      (goto-char (point-min))
+      (search-forward "('")
+(delete-region (point-min) (point))
+(goto-char (point-max))
+(search-backward "'")
+(delete-region (point) (point-max))
+(w3-fetch 
+(buffer-string)))))
+
+
+
+
+(define-key w3-mode-map "\M-j" 'emacspeak-w3-javascript-follow-link)
+
 ;;}}}
 (provide 'emacspeak-w3)
 ;;{{{  emacs local variables 
