@@ -1,22 +1,22 @@
 ;;; emacspeak-widget.el --- Speech enable Emacs' native GUI widget library
-;;; $Id: emacspeak-widget.el,v 9.0 1998/10/24 05:17:28 raman Exp $
+;;; $Id: emacspeak-widget.el,v 11.0 1999/11/29 16:58:57 raman Exp $
 ;;; $Author: raman $ 
 ;;; Description: Emacspeak extensions to widgets
 ;;; Keywords:emacspeak, audio interface to emacs customized widgets
 ;;{{{  LCD Archive entry: 
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@adobe.com
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 1998/10/24 05:17:28 $ |
-;;;  $Revision: 9.0 $ | 
+;;; $Date: 1999/11/29 16:58:57 $ |
+;;;  $Revision: 11.0 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995, 1996, 1997, 1998   T. V. Raman  Adobe Systems Incorporated
-;;; Copyright (c) 1995 by T. V. Raman Adobe Systems Incorporated 
+;;;Copyright (C) 1995, 1996, 1997, 1998, 1999   T. V. Raman  
+;;; Copyright (c) 1995 by T. V. Raman  
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -313,7 +313,8 @@ ad-return-value))
 
 (defadvice widget-button-press (around emacspeak pre act comp)
   "Provide auditory feedback"
-  (let ((widget (widget-at (ad-get-arg 0))))
+  (let ((inhibit-read-only t)
+        (widget (widget-at (ad-get-arg 0))))
     (cond
      (widget                            ; First record some state:
       (let ((pos (ad-get-arg 0))
@@ -399,6 +400,19 @@ widget before summarizing."
        (t (read-key-sequence "Press any key to continue")))
       (emacspeak-widget-summarize-widget-under-point level))))
 
+;;}}}
+;;{{{ work around widget problems
+(defadvice widget-convert-text (around emacspeak pre act comp)
+  "Protect value of personality if set originally"
+  (let ((start (ad-get-arg 1))
+        (end (ad-get-arg 2))
+        (orig nil ))
+    (setq orig (get-text-property start 'personality))
+    ad-do-it 
+    (and orig 
+         (put-text-property start end 
+                            'personality orig ))))
+
 ;;}}}
 (provide  'emacspeak-widget)
 ;;{{{  emacs local variables 
